@@ -3,7 +3,7 @@ register_class("data.table")
 # to ---------------------------------------------------------------------------
 
 ts_data.table_dts <- function(x) {
-  dts_rm(x)
+  dts_rm(x)[]
 }
 
 
