@@ -26,10 +26,11 @@
 #' \donttest{
 #' ts_plot(AirPassengers, ts_lag(AirPassengers), title = "Illustrating the need for glasses")
 #' }
-#' head(ts_lag(AirPassengers, "1 month"))
-#' head(ts_lag(AirPassengers, "1 year"))
-#' head(ts_lag(ts_df(AirPassengers), "2 day"))
-#' # head(ts_lag(ts_df(AirPassengers), "2 min")) not yet working
+#' head(ts_lag(fdeaths, "1 month"))
+#' head(ts_lag(fdeaths, "1 year"))
+#' head(ts_lag(ts_df(fdeaths), "2 day"))
+#' head(ts_lag(ts_df(fdeaths), "2 min"))
+#' head(ts_lag(ts_df(fdeaths), "-1 day"))
 #' @export
 ts_lag <- function(x, by = 1) {
 
@@ -52,8 +53,7 @@ ts_lag <- function(x, by = 1) {
   lag_one <- function(x){
     x[, list(time = time_shift(time, by = by), value)]
   }
-
-  .by <- parse(text = paste0("list(", paste(cname$id, collapse = ", "), ")"))
+  .by <- by_expr(cname$id)
   z <- z[
     ,
     lag_one(.SD),
